Function from_raw
Source pub const fn from_raw(value: Options) -> Builder
Construct a Builder from the raw underlying value of an Options.
This can be used to modify a value at compile time.
Examples
use musli::options::{self, Float, Options};
const BASE: Options = options::new().build();
const MODIFIED: Options = options::from_raw(BASE).float(Float::Fixed).build();