Limit

Struct Limit 

pub struct Limit<R> { /* private fields */ }
Limit the number of bytes that can be read out of a reader to the specified limit.

This type wraps another reader and ensures that no more than a specified number of bytes can be read from it. This is useful for implementing bounded reads in serialization contexts.

Constructed through Reader::limit.

Examples

use musli::Context;
use musli::reader::{Reader, SliceReader};

let cx = musli::context::new();
let data = &[1, 2, 3, 4, 5];
let mut reader = SliceReader::new(data);
let mut limited = reader.limit(3);

// Can read from the limited reader
let byte = limited.read_byte(&cx)?;
assert_eq!(byte, 1);
assert_eq!(limited.remaining(), 2);

// Read two more bytes
limited.read_byte(&cx)?;
limited.read_byte(&cx)?;
assert_eq!(limited.remaining(), 0);

Implementations

Source

impl<R> Limit<R>

pub fn remaining(&self) -> usize

Get the remaining data in the limited reader.

Returns the number of bytes that can still be read from this limited reader before the limit is reached.

Examples
use musli::reader::{Reader, SliceReader};

let data = &[1, 2, 3, 4, 5];
let mut reader = SliceReader::new(data);
let limited = reader.limit(3);

assert_eq!(limited.remaining(), 3);